﻿using MineServer.Model;
using MongoDB.Driver;

namespace MineServer.Services
{
    public class PlayerInfoQueryService
    {
        private readonly MongoDBService _db;

        private readonly IMongoCollection<PlayerInfo> collection;

        public PlayerInfoQueryService(MongoDBService db)
        {
            _db = db;
            collection = _db.Client.GetDatabase("MineDB").GetCollection<PlayerInfo>("PlayerInfo");
        }

        public PlayerInfo NewPlayerInfo(string openid, string session_key)
        {
            PlayerInfo newPlayer = new PlayerInfo()
            {
                openid = openid,
                session_key = session_key,
                PlayerData = new PlayerData()
            };
            collection.InsertOne(newPlayer);
            Console.WriteLine($"添加新角色{openid}");
            return newPlayer;
        }
        public async Task<PlayerInfo> GetPlayerIInfo(string openid)
        {
            return await collection.Find(t => t.openid == openid).FirstOrDefaultAsync();
        }

        public void RefreshUpgrades(PlayerInfo player)
        {
            player.PlayerData.UpgradeInfos = UpgradeInfos.Where(t=>!player.CompletedUpgrades.Contains(t.ID)&&(t.PreID==0||player.CompletedUpgrades.Contains(t.PreID))).ToList();
        }

        public void RefreshWorkbenchInfos(PlayerInfo player)
        {
            player.PlayerData.WorkbenchInfos = WorkbenchInfos;
        }


        //升级项目
        public static List<UpgradeInfo> UpgradeInfos = new List<UpgradeInfo>()
    {

        new UpgradeInfo()
        {
            ID=1,
            Name="传送法阵1",
            Description="扩大法阵以存储更多的传送宝石。",
            UpgradeType=UpgradeType.TicketLimit,
            Value=1,
            Demands=new Dictionary<string, int> { {"金币",200 },{"月光石",5 } },
            PreID=0
        },
        new UpgradeInfo()
        {
                        ID=2,
            Name="传送法阵2",
            Description="扩大法阵以存储更多的传送宝石。",
            UpgradeType=UpgradeType.TicketLimit,
            Value=1,
            Demands=new Dictionary<string, int> { {"金币",200 },{"月光石",5 },{"紫钻",5} },
            PreID=1
        }
        ,
        new UpgradeInfo()
        {
            ID = 3,
            Name="二层传送梯",
            Description="打通直接前往二层深度传送门。",
            UpgradeType=UpgradeType.StartLevel,
            Value=2,
            Demands=new Dictionary<string, int> { { "金币", 100 } },
            PreID=0
        }
        ,
        new UpgradeInfo()
        {
             ID=4,
            Name="友情之力",
            Description="向好友分享游戏，就能得到好友的助力。",
            UpgradeType=UpgradeType.Manual,
            Value=2,
            Demands=new Dictionary<string, int> { { "Share", 1 } },
            PreID=0
        },
       new UpgradeInfo()
        {
            ID=0,
            Name="入门设备",
            Description="更好的设备能够更轻松的挖掘矿石。",
            UpgradeType=UpgradeType.Manual,
            Value=5,
            Demands=new Dictionary<string, int> { {"金币",100 } },
            PreID=0
        },
    };

        //工艺任务
        public static List<WorkbenchInfo> WorkbenchInfos = new List<WorkbenchInfo>()
    {
        new WorkbenchInfo()
        {
            ID=0,
            Name="任务一",
            RewardName="金币",
            RewardCount=100,
            Description="制作需求的工艺品能够换取金币。",
            Demands=new Dictionary<string, int> { {"红宝石",5 },{"月光石",5 } },
        },
        new WorkbenchInfo()
        {
            ID=1,
            Name="任务二",
            RewardName="金币",
            RewardCount=200,
            Description="制作需求的工艺品能够换取金币。",
            Demands=new Dictionary<string, int> { {"红宝石",5 },{"月光石",5 } },
        },
        new WorkbenchInfo()
        {
            ID=2,
            Name="任务三",
            RewardName="金币",
            RewardCount=100,
            Description="制作需求的工艺品能够换取金币。",
            Demands=new Dictionary<string, int> { {"月光石",3 } },
        },
    };
    }
}
